==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qnx/blackberrydeployconfigurationwidget.cpp <==
/**************************************************************************
**
** Copyright (C) 2012, 2013 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "blackberrydeployconfigurationwidget.h"
#include "ui_blackberrydeployconfigurationwidget.h"
#include "blackberrydeployconfiguration.h"
#include "blackberrydeployinformation.h"
#include "pathchooserdelegate.h"

#include <coreplugin/icore.h>
#include <projectexplorer/devicesupport/devicemanager.h>
#include <projectexplorer/projectexplorerconstants.h>
#include <utils/pathchooser.h>

using namespace Qnx;
using namespace Qnx::Internal;

BlackBerryDeployConfigurationWidget::BlackBerryDeployConfigurationWidget(BlackBerryDeployConfiguration *dc,
                                                                         QWidget *parent)
    : ProjectExplorer::NamedWidget(parent)
    , m_ui(new Ui::BlackBerryDeployConfigurationWidget)
    , m_deployConfiguration(0)
{
    m_ui->setupUi(this);
    m_deployConfiguration = dc;

    m_ui->deployPackagesView->setModel(m_deployConfiguration->deploymentInfo());

    PathChooserDelegate *appDescriptorPathDelegate = new PathChooserDelegate(this);
    appDescriptorPathDelegate->setExpectedKind(Utils::PathChooser::File);
    appDescriptorPathDelegate->setPromptDialogFilter(QLatin1String("*.xml"));

    PathChooserDelegate *barPathDelegate = new PathChooserDelegate(this);
    barPathDelegate->setExpectedKind(Utils::PathChooser::File);
    barPathDelegate->setPromptDialogFilter(QLatin1String("*.bar"));

    m_ui->deployPackagesView->setItemDelegateForColumn(1, appDescriptorPathDelegate);
    m_ui->deployPackagesView->setItemDelegateForColumn(2, barPathDelegate);

    m_ui->deployPackagesView->header()->resizeSections(QHeaderView::ResizeToContents);
}

BlackBerryDeployConfigurationWidget::~BlackBerryDeployConfigurationWidget()
{
    delete m_ui;
}

==> qt-creator-opensource-src-3.1.2.zip: qt-creator-opensource-src-3.1.2/src/plugins/qnx/blackberrydeployconfigurationwidget.cpp <==
/**************************************************************************
**
** Copyright (C) 2012 - 2014 BlackBerry Limited. All rights reserved.
**
** Contact: BlackBerry (qt@blackberry.com)
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "blackberrydeployconfigurationwidget.h"
#include "ui_blackberrydeployconfigurationwidget.h"
#include "blackberrydeployconfiguration.h"
#include "blackberrydeployinformation.h"
#include "pathchooserdelegate.h"

#include <coreplugin/icore.h>
#include <projectexplorer/devicesupport/devicemanager.h>
#include <projectexplorer/projectexplorerconstants.h>
#include <utils/pathchooser.h>

using namespace Qnx;
using namespace Qnx::Internal;

BlackBerryDeployConfigurationWidget::BlackBerryDeployConfigurationWidget(BlackBerryDeployConfiguration *dc,
                                                                         QWidget *parent)
    : ProjectExplorer::NamedWidget(parent)
    , m_ui(new Ui::BlackBerryDeployConfigurationWidget)
    , m_deployConfiguration(0)
{
    m_ui->setupUi(this);
    m_deployConfiguration = dc;

    m_ui->deployPackagesView->setModel(m_deployConfiguration->deploymentInfo());

    PathChooserDelegate *appDescriptorPathDelegate = new PathChooserDelegate(this);
    appDescriptorPathDelegate->setExpectedKind(Utils::PathChooser::File);
    appDescriptorPathDelegate->setHistoryCompleter(QLatin1String("BB.BarXml.History"));
    appDescriptorPathDelegate->setPromptDialogFilter(QLatin1String("*.xml"));

    PathChooserDelegate *barPathDelegate = new PathChooserDelegate(this);
    barPathDelegate->setExpectedKind(Utils::PathChooser::File);
    barPathDelegate->setHistoryCompleter(QLatin1String("BB.AppBar.History"));
    barPathDelegate->setPromptDialogFilter(QLatin1String("*.bar"));

    m_ui->deployPackagesView->setItemDelegateForColumn(1, appDescriptorPathDelegate);
    m_ui->deployPackagesView->setItemDelegateForColumn(2, barPathDelegate);

    m_ui->deployPackagesView->header()->resizeSections(QHeaderView::ResizeToContents);
}

BlackBerryDeployConfigurationWidget::~BlackBerryDeployConfigurationWidget()
{
    delete m_ui;
}
